# DOHSPEC -- Process Hectospec spectra from 2D to wavelength calibrated 1D.
# By Doug Mink, SAO Telescope Data Center (based on dofibers)
# Jun 16, 2004
#
# The task PROC does all of the interactive work and BATCH does the
# background work.  This procedure is organized this way to minimize the
# dictionary space when the background task is submitted.

procedure dohspec (objects)

string	objects = ""		{prompt="List of object spectra"}

file	apref = ""		{prompt="Aperture reference spectrum"}
file	flat = ""		{prompt="Flat field spectrum"}
file	throughput = ""		{prompt="Throughput file or image (optional)"}
string	arcs1 = ""		{prompt="List of arc spectra"}
string	arcs2 = ""		{prompt="List of shift arc spectra"}
file	arcreplace = ""		{prompt="Special aperture replacements"}
file	arctable = ""		{prompt="Arc assignment table (optional)\n"}

string	readnoise = "RDNOISE"	{prompt="Read out noise sigma (photons)"}
string	gain = "GAIN"		{prompt="Photon gain (photons/data number)"}
real	datamax = INDEF		{prompt="Max data value / cosmic ray threshold"}
int	fibers = 150		{prompt="Number of fibers"}
real	width = 9.		{prompt="Width of profiles (pixels)"}
real	minsep = 3.	{prompt="Minimum separation between fibers (pixels)"}
real	maxsep = 50.	{prompt="Maximum separation between fibers (pixels)"}
file	apidtable = ""		{prompt="Aperture identifications"}
string	crval = "INDEF"		{prompt="Approximate central wavelength"}
string	cdelt = "INDEF"		{prompt="Approximate dispersion"}
string	objaps = ""		{prompt="Object apertures"}
string	skyaps = ""		{prompt="Sky apertures"}
string	arcaps = ""		{prompt="Arc apertures"}
string	objbeams = "1"		{prompt="Object beam numbers"}
string	skybeams = "0"		{prompt="Sky beam numbers"}
string	arcbeams = ""		{prompt="Arc beam numbers\n"}

bool	recenter = no		{prompt="Recenter object apertures?"}
bool	resize = no		{prompt="Resize object apertures?"}
bool	scattered = no		{prompt="Subtract scattered light?"}
bool	fitflat = no		{prompt="Fit and ratio flat field spectrum?"}
bool	clean = no		{prompt="Detect and replace bad pixels?"}
bool	dispcor = yes		{prompt="Dispersion correct spectra?"}
bool	savearcs = no		{prompt="Save simultaneous arc apertures?"}
bool	skyalign = yes		{prompt="Align sky lines?"}
bool	skysubtract = yes	{prompt="Subtract sky?"}
bool	skyedit = no		{prompt="Edit the sky spectra?"}
bool	saveskys = yes		{prompt="Save sky spectra?"}
bool	splot = no		{prompt="Plot the final spectrum?"}
bool	redo = no		{prompt="Redo operations if previously done?"}
bool	update = no		{prompt="Update spectra if cal data changes?"}
bool	batch = no		{prompt="Extract objects in batch?"}
bool	listonly = no		{prompt="List steps but don't process?\n"}
bool	shift = yes		{prompt="Use average shift instead of recentering?"}
real	npeaks = 0.2		{prompt="Select brightest peaks"}

pset	params = ""		{prompt="Algorithm parameters"}

begin
	apscript.recenter = recenter
	apscript.shift = shift
	apscript.npeaks = npeaks
	apscript.readnoise = readnoise
	apscript.gain = gain
	apscript.nfind = fibers
	apscript.width = width
	apscript.t_width = width
	apscript.minsep = minsep
	apscript.maxsep = maxsep
	apscript.radius = minsep
	apscript.clean = clean
	apscript.resize = resize
	proc.datamax = datamax

	proc (objects, apref, flat, throughput, arcs1, arcs2, arcreplace,
	    arctable, fibers, apidtable, crval, cdelt, objaps, skyaps,
	    arcaps, objbeams, skybeams, arcbeams, scattered, fitflat, recenter,
	    no, no, no, clean, dispcor, savearcs, skyalign, skysubtract,
	    skyedit,saveskys,splot,redo,update,batch,listonly)

	if (proc.dobatch) {
	    print ("-- Do remaining spectra as a batch job --")
	    print ("batch&batch") | cl
	}
end
# Jun 15 2004	Add parameter recenter to pass to proc
# Jun 16 2004	Sep more apscript parameters
