# HDISP1 -- Dispersion correct spectrum, placing input in Nodisp/
# By Doug Mink, SAO Telescope Date Center
# May 24, 2005

procedure hdisp1 (image)

string	image = ""	{prompt="Input multispec image to correct"}
string	calfile=""	{prompt="Calibration file for dispersion correction"}
bool saveold = yes	{prompt="Save original files in Nodisp/ (y or n)"}
bool verbose = no	{prompt="Log progress (y or n)"}
bool debug = no		{prompt="Too much info from sumspec (y or n)"}

begin
	bool vb, db, save
	file imin, imdisp, imroot, imcal, newfile
	string history
	int lroot, lref

	imin = image
	imcal = calfile
	vb = verbose
	db = debug
	if (db) {
	    vb = yes
	    }
	save = saveold

	if (imin == "") {
	    print ("HDISP1:  Dispersion-correct multispec file of spectra")
	    print ("Usage: hdisp1 <input image>")
	    return
	    }

# Remove extension from calibration file, if one is present
	smatch (imcal, ".fits")
	if (smatch.found) {
	    lref = smatch.start - 1
	    imcal = substr (imcal, 1, lref)
	    }

# Make output file name and check to make sure input is multispec
	smatch (imin, ".ms")
	if (smatch.found) {
	    lroot = smatch.start - 1
	    imroot = substr (imin, 1, lroot)
	    smatch (imin, ".fits")
	    if (!smatch.found) {
		imin = imin // ".fits"
		}
	    }
	else {
	    smatch (imin, ".fits")
	    if (smatch.found) {
		lroot = smatch.start - 1
		imroot = substr (imin, 1, lroot)
		imin = imroot // ".ms.fits"
		}
	    else {
		imroot = imin
		imin = imroot // ".ms.fits"
		}
	    }
	if (!access (imin)) {
	    print ("HLIN: ", imin," does not exist")
	    return
	    }

# Do not linearize image twice
	imgetp.default = "0"
	imgetp (imin, "HDISP")
	if (imgetp.value != "0") {
	    if (vb) {
		print ("HDISP1: ", imin, " already has a dispersion function")
		print ("HDISP = ", imgetp.value)
		}
	    return
	    }

# Dispersion-correct file
	if (vb) {
	    print ("HDISP: Set REFSPEC1 in ",imin," to ",imcal)
	    }
	hedit (imin, "REFSPEC1", imcal, verify=no,show=vb,add=yes,update=yes)
#	refspec (imin, references=imcal)
	imdisp = imroot // ".disp.ms.fits"
	dispcor (imin, imdisp, linearize=no)

# Save original file, if requested
	if (save) {
	    if (!access ("Nodisp/")) {
		mkdir ("Nodisp")
		}
	    newfile = "Nodisp/" // imin
	    if (access (newfile)) {
		imdelete (newfile)
		}
	    movefiles (imin, "Nodisp")
	    if (vb) {
		print ("HDISP1: Original ", imin, " => Nodisp/")
		}
	    }
	else {
	    delete (imin)
	    }

# Rename processed file to input file name
	rename (imdisp, imin)

# Add history line including time
	gettime ()
	history = gettime.date // " " // gettime.time // " image dispersion from " // imcal
        hedit (imin, "HDISP", history, add+, verify-, show-)

end

# May 19 2005	New task split from HLIN1
# May 24 2005	Add calibration file name to HDISP keyword value
