# MAKETRAN -- Make a fiber transmission correction file
# By Doug Mink, SAO/TDC
# January 12, 2005

procedure maketran (input, output)

string	input = ""	{prompt="Input multispec image from which to make a correction file"}
string	output = "pixtran.ms.fits"	{prompt="Output multispec correction file"}

string apertures = "141-146"	{prompt="Range of apertures to median for normalization"}
file badlines = "badskyab.dat"	{prompt="Lines to eliminate from spectrum before fitting"}
file linedir = "hectospec$lib/"	{prompt="Directory for line list"}
string function = "spline3"	{prompt="Function for spectrum fit"}
int  order = 20		{prompt="Order of spectrum fit"}
bool interact = no	{prompt="Interact with transmission fit"}
bool deltemp = yes	{prompt="Delete temporary files (y or n)"}
bool verbose = yes	{prompt="Log each aperture (y or n)"}
bool intfit = no	{prompt="Run continuum fits interactively (y or n)"}

begin
	string history
	file imin, imout, temp1, temp2, temp3, temp4
	bool vb, db
	int nap

	imin = input
	imout = output
	vb = verbose
	db = intfit
	if (imout == "") {
	    print ("MAKETRAN: missing output file")
	    return
	    }

# Find out how many apertures there are in this multispec file
	imgetp.default = "0"
	imgetp (imin, "i_naxis2")
	nap = int (imgetp.value)

# Make a mean sky spectrum from selected apertures
	temp1 = mktemp ("mtran")
	scombine.input = imin
	scombine.output = temp1
	scombine.noutput = ""
	scombine.logfile = "STDOUT"
	scombine.apertures = apertures
	scombine.group = "image"
	scombine.combine = "average"
	scombine.reject = "none"
	scombine.first = yes
	scombine.w1 = INDEF
	scombine.w2 = INDEF
	scombine.dw = INDEF
	scombine.nw = INDEF
	scombine.log = no
	scombine.scale = "none"
	scombine.zero = "none"
	scombine.weight = "none"
	scombine.sample = ""
	scombine.lthreshold = INDEF
	scombine.hthreshold = INDEF
	scombine.nlow = 1
	scombine.nhigh = 1
	scombine.nkeep = 1
	scombine.mclip = no
	scombine.lsigma = 3.
	scombine.hsigma = 3.
	scombine.rdnoise = "0."
	scombine.gain = "1."
	scombine.snoise = "0."
	scombine.sigscale = 0.1
	scombine.pclip = -0.5
	scombine.grow = 0
	scombine.blank = 0.
	scombine (imin, temp1)

# Replicate mean spectrum into full multispec image
	temp2 = mktemp ("mtran") // ".ms.fits"
	imstack (temp1, temp2)
	temp3 = mktemp ("mtran") // ".ms.fits"
	blkrep (temp2, temp3, 1, nap)

# Divide all spectra by mean spectrum
	temp4 = mktemp ("mtran") // ".ms.fits"
	imarith (imin, "/", temp3, temp4, divzero=1.0, verbose=vb)

# Fit each spectrum for transmission
#	rvsao (motd=no)
        imgetp (imin, "i_naxis1", verbose=vb)
        sumspec.npts = int (imgetp.value)
        imgetp (imin, "CRVAL1", verbose=vb)
        sumspec.st_lambda = real (imgetp.value)
        imgetp (imin, "CD1_1", verbose=vb)
        sumspec.pix_lambda = real (imgetp.value)
        sumspec.end_lambda = INDEF
	if (badlines != "") {
	    sumspec.fixbad = yes
	    sumspec.badlines = badlines
	    sumspec.linedir = linedir
	    }
	else {
	    sumspec.fixbad = no
	    }
	contsum.c_interactive = db
	contsum.c_sample = "*"
	contsum.c_function = function
	contsum.naverage = 1
	contsum.order = order
	contsum.s_low_reject = 3.
	contsum.s_high_reject = 4.
	contsum.niterate = 10
	contsum.grow = 1.
	sumspec.cont_remove = "no"
	sumspec.contout = "fit"
	sumspec.comp_plot = vb
	sumspec.comp_int = interact
	sumspec.specnum = "1-" // nap
	sumspec.nspec = nap
	sumspec (temp4, imout)

# Delete temporary files
	if (deltemp) {
	    imdel (temp1)
	    imdel (temp2)
	    imdel (temp3)
	    imdel (temp4)
	    }

# Add history line including time about this transmission correction file
	gettime ()
	history = gettime.date // " " // gettime.time // " transmission correction from " // imin
	hedit (imout, "MAKETRAN", history, add+, verify-)
	hedit (imout, "TRANFUNC", function, add+, verify-)
	hedit (imout, "TRANORD", order, add+, verify-)
	hedit (imout, "TRANAPS", apertures, add+, verify-)

end

# Jun  8 2004	New task

# Jan 12 2005	Set number of apertures from input image dimension
# Jan 12 2005	Add option to fit continuum interactively
